@@ -6,7 +6,7 @@ SNMP::Effective - An effective SNMP-information-gathering module
 
 =head1 VERSION
 
-1.0801
+1.09
 
 =head1 SYNOPSIS
 
@@ -88,7 +88,7 @@ use POSIX qw(:errno_h);
 
 use base qw/ SNMP::Effective::Dispatch /;
 
-our $VERSION = eval '1.0801';
+our $VERSION = eval '1.09';
 our %SNMPARG = (
     Version => '2c',
     Community => 'public',
@@ -286,9 +286,9 @@ sub add {
             my $host = $hostlist->get_host($addr)
                     || $hostlist->add_host(
                            address => $addr,
-                           arg => $self->arg,
-                           callback => $self->callback,
-                           heap => $self->heap,
+                           arg => $in{'args'} || $self->arg,
+                           callback => $in{'callback'} || $self->callback,
+                           heap => $in{'heap'} || $self->heap,
                        );
 
             push @$host, (@$host or @new_varlist) ? @new_varlist : @$varlist;
@@ -591,3 +591,6 @@ under the same terms as Perl itself.
 =cut
 
 1;
+t
+
+1;
